import React, { useState, useEffect, useRef } from 'react'
import styled from 'styled-components'
import {
  Form,
  Select,
  Input,
  Radio,
  Space,
  message,
  Divider,
  Button,
} from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { getTagList } from '../services'

const FormWrapper = styled.div`
  .singletask_form {
    margin-top: 20px;
  }
  .form_executionCycle {
    margin-left: 10px;
  }
`

const FormItem = Form.Item

const { Option } = Select

const RadioGroup = Radio.Group

const layout = {
  labelCol: {
    span: 2,
  },
  wrapperCol: {
    span: 8,
  },
}

const units = {
  分: 'min',
  时: 'hour',
  日: 'day',
  周: 'week',
  月: 'month',
}

const TaskForm = ({
  taskForm,
  taskType,
  taskInfo,
  jmWorkList,
  setCronNum,
  setCronUnit,
}) => {
  const [radioValue, setRadioValue] = useState(null)
  const [cronNumValue, setCronNumValue] = useState('')
  const [cronUnitValue, setCronUnitValue] = useState(null)
  const [tagOptions, setTagOptions] = useState([])
  const [jmWorkOptions, setJmWorkOptions] = useState([])
  const [tag, setTag] = useState(null)
  const inputRef = useRef(null)

  const onNameChange = event => {
    setTag(event.target.value)
  }

  const addItem = e => {
    e.preventDefault()
    if (tag !== null) {
      setTagOptions([...tagOptions, tag])
      setTag(null)
    }
    setTimeout(() => {
      inputRef.current?.focus()
    }, 0)
  }

  const onRadioChange = e => {
    setRadioValue(e.target.value)
  }

  const onCronNumChange = e => {
    setCronNumValue(e.target.value)
    setCronNum(e.target.value)
  }

  const onCronUnitChange = params => {
    console.log(params)
    setCronUnitValue(params)
    setCronUnit(params?.label)
  }

  const fetchTagList = async () => {
    const { data } = await getTagList('任务分类')
    if (data.code === 200) {
      setTagOptions(data.data)
    } else {
      message.error(data.msg)
    }
  }

  const handleInitTask = taskInfo => {
    console.log(taskInfo)
    setRadioValue(taskInfo.cron_type)
    if (taskInfo.cron_type === 2) {
      setCronNumValue(taskInfo.cron_num)
      setCronNum(taskInfo.cron_num)
      setCronUnitValue({
        value: units[taskInfo.cron_unit],
        label: taskInfo.cron_unit,
      })
      setCronUnit(taskInfo.cron_unit)
    }
    taskForm.setFieldsValue({
      taskName: taskInfo.name,
      taskTag: taskInfo.tag,
      job: taskInfo.nodes[0].homework_id,
      executionCycle: taskInfo.cron_type,
    })
  }

  //初始化tag列表
  useEffect(() => {
    fetchTagList()
  }, [])

  //初始化作业列表
  useEffect(() => {
    setJmWorkOptions(jmWorkList)
  }, [jmWorkList])

  useEffect(() => {
    if (taskInfo !== null) handleInitTask(taskInfo)
  }, [taskInfo])

  return (
    <FormWrapper>
      <Form {...layout} form={taskForm} className="singletask_form">
        <FormItem
          name="taskName"
          label="任务名称"
          rules={[{ required: true, message: '请输入任务名称!' }]}>
          <Input />
        </FormItem>
        <FormItem
          name="taskTag"
          label="任务分类"
          rules={[{ required: true, message: '请选择任务分类!' }]}>
          <Select
            placeholder="选择任务分类"
            allowClear
            dropdownRender={menu => (
              <>
                {menu}
                <Divider
                  style={{
                    margin: '8px 0',
                  }}
                />
                <Space
                  style={{
                    padding: '0 8px 4px',
                  }}>
                  <Input
                    placeholder="请输入"
                    ref={inputRef}
                    value={tag}
                    onChange={onNameChange}
                  />
                  <Button type="text" icon={<PlusOutlined />} onClick={addItem}>
                    添加新分类
                  </Button>
                </Space>
              </>
            )}>
            {tagOptions.map((item, index) => (
              <Option key={index} value={item}>
                {item}
              </Option>
            ))}
          </Select>
        </FormItem>
        {taskType !== 'multitasking' && (
          <FormItem
            name="job"
            label="选择作业"
            rules={[{ required: true, message: '请选择作业!' }]}>
            <Select placeholder="选择作业" allowClear>
              {jmWorkOptions.map(item => (
                <Option key={item.id} value={item.id}>
                  {item.name}
                </Option>
              ))}
            </Select>
          </FormItem>
        )}
        <FormItem
          name="executionCycle"
          label="设置执行周期"
          rules={[{ required: true, message: '请设置执行周期!' }]}>
          <RadioGroup onChange={onRadioChange}>
            <Space direction="vertical">
              <Radio value={1}>只执行一次，下次手动执行</Radio>
              <Radio value={2}>
                执行周期
                {radioValue === 2 ? (
                  <Space className="form_executionCycle">
                    <span>每</span>
                    <input
                      style={{ width: '50px' }}
                      value={cronNumValue}
                      onChange={onCronNumChange}
                    />
                    <Select
                      placeholder="选择数"
                      allowClear
                      labelInValue
                      value={cronUnitValue}
                      onChange={onCronUnitChange}>
                      <Option value="min">分</Option>
                      <Option value="hour">时</Option>
                      <Option value="day">日</Option>
                      <Option value="week">周</Option>
                      <Option value="month">月</Option>
                    </Select>
                    <span>执行1次</span>
                  </Space>
                ) : null}
              </Radio>
            </Space>
          </RadioGroup>
        </FormItem>
      </Form>
    </FormWrapper>
  )
}

export default TaskForm
