import { Button, Form, Input, Select, Radio, Space, Upload, Steps, Divider } from 'antd';
import { UploadOutlined, PlusOutlined } from '@ant-design/icons';
import setFieldValue from 'antd';
import React, { useState , Component , useEffect, useRef } from 'react';
import bus from '../../../bus.js'
import ButtonGroup from 'antd/lib/button/button-group.js';
import { getJobTypes, getDagFile } from '../services'
const { Option } = Select;
const FormItem = Form.Item


const layout = {
  labelCol: {
    span: 8,
  },
  wrapperCol: {
    span: 16,
  },
};
const tailLayout = {
  wrapperCol: {
    offset: 8,
    span: 16,
  },
};

export default function JobStepOne({ ConfigDataForm }) {
  const [form] = Form.useForm();
  
  const JobTagInputRef = useRef(null);
  //自定义作业分类名称
  const [tagName, setTagName] = useState('');
  //作业分类
  const [jobTags, setJobTags] = useState([])

  const [dags, setDags] = useState([])

  useEffect(() => {
    const DJName = ConfigDataForm.getFieldValue('DagJobName')
    if (DJName) {
      ConfigDataForm.setFieldValue('DagJobName',DJName)
      console.log(ConfigDataForm)
    }
    getJobType()
    getDags()
  },[])
  
  //获取作业分类
  const getJobType = async () => {
    const JobTags = await getJobTypes('作业分类')
    console.log(JobTags);
    if (JobTags.data.code === 200) {
      setJobTags(JobTags.data.data)
    }
  }
  
  //获取DAG
  const getDags = async () => {
    const params = {
      project_id: 'test',
      user_id: 'test',
    }
    const data = await getDagFile(params)
    setDags(data.data.data)

  }

  const onNameChange = (event) => {
    setTagName(event.target.value);
  };
  
  //添加自定义作业分类
  const addTagItem = (e) => {
    e.preventDefault();
    setJobTags([...jobTags,tagName])
    setTagName('')
    setTimeout(() => {
      JobTagInputRef.current?.focus();
    }, 0);
  };

  //向第二步传递选择的DAG算子
  const sendDag = () => {
    const choseDag = ConfigDataForm.getFieldValue().DagMirror
    bus.emit('DAGSend',choseDag)
    console.log(ConfigDataForm.getFieldValue().DagMirror);
  }
  return (
    <>
    <Form  {...layout} form={ConfigDataForm} name="control-hooks" >
      <FormItem
        name="name"
        label="作业名称"
        rules={[
          {
            required: true,
          },
        ]}
      >
        <Input
          placeholder="请输入作业名称..."
          allowClear
          // onChange={}
        >
        </Input>
      </FormItem>
    
    {/* 作业分类选择 */}
      <FormItem
        name="tag"
        label="作业分类"
        rules={[
          {
            required: true,
          },
        ]}
      >
        <Select
          placeholder="请选择作业分类..."
          allowClear
          dropdownRender={(menu) => (
        <>
          {menu}
          <Divider
            style={{
              margin: '8px 0',
            }}
          />
          <Space
            style={{
              padding: '0 8px 4px',
            }}
          >
            <Input
              placeholder="添加作业分类"
              ref={JobTagInputRef}
              value={tagName}
              onChange={onNameChange}
            />
            <Button type="text" icon={<PlusOutlined />} onClick={addTagItem}>
              添加分类
            </Button>
          </Space>
        </>
      )}
        >
        {jobTags.map((item) => (
          <Option key={item}>{item}</Option>
          ))
        }
        </Select>
      </FormItem>

    {/* 选择执行镜像 */}
      <FormItem
        className='mirrorLeft'
        name="dag_url"
        label="选择DAG算子"
        rules={[
          {
            required: true,
            message: '请选择DAG算子',
          },
        ]}
      >
        <Select
          placeholder="请选择DAG算子"
          allowClear
          onSelect={sendDag}
          >
          {dags.map((item) => (
          <Option key={item}>{item}</Option>
          ))
        }
        </Select>
      </FormItem>
    </Form>
    </>
  )
}